Learn R Programming

BUS (version 1.28.0)

gene.trait.similarity: Calculate similarity for gene-trait interaction

Description

To calculate similarity for gene-trait interaction (using correlation/mutual information metric).

Usage

gene.trait.similarity(EXP, trait, measure, na.replica = 50)

Arguments

EXP
Gene expression data in form of a matrix. Row stands for genes and column for experiments.
trait
Trait data in form of matrix. Row stands for traits and column for experiments.
measure
Metric used to calculate similarity: "corr" for correlation, "MI" for mutual information.
na.replica
Times of replicates for filling NANs in impute method; default value is 50. The (smooth) bootstrapping approach is used to give an estimation to missing value in the data.

Value

A matrix, row stands for gene and column for trait. Element in row i and column j stands for the association between the gene i and trait j.

Examples

Run this code
data(tumors.mRNA)
data(tumors.miRNA)
exp<-tumors.mRNA
trait<-tumors.miRNA
gene.trait.similarity(EXP= exp[1:10, ],trait= trait[1:5, ],measure="MI")

Run the code above in your browser using DataLab