Learn R Programming

BUS (version 1.28.0)

tumors.miRNA: miRNA data from Human brain tumors

Description

MiRNA data obtained by RT-PCR from human brain tumors. 12 brain tumors at different levels are analyzed for both mRNA and miRNA levels to study the correlation of any mRNA-miRNA pair in the reference .

Usage

data(tumors.miRNA)

Arguments

Format

tumors.miRNA is a matrix with miRNA as rows and tumor type as columns.

References

Liu T, Papagiannakopoulos T, Puskar K, Qi S, Santiago F, Clay W, Lao K, Lee Y, Nelson SF, Kornblum HI, Doyle F, Petzold L, Shraiman B, Kosik KS. Detection of a microRNA signal in an in vivo expression set of mRNAs. Plos One. 2007; 2(8):e804.

Examples

Run this code
data(tumors.miRNA)
tumors.miRNA[1:10,]

Run the code above in your browser using DataLab