Gene expression data in form of a matrix. Row stands for genes and column for experiments.
trait
Trait data in form of matrix. Row stands for traits and column for experiments.
measure
Metric used to calculate similarity: "corr" for correlation, "MI" for mutual information.
na.replica
Times of replicates for filling NANs in impute method; default value is 50. The (smooth) bootstrapping approach is used to give an estimation to missing value in the data.
Value
A matrix, row stands for gene and column for trait. Element in row i and column j stands for the association between the gene i and trait j.